{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Make directory if not exists",
            "doc": "Make directory if not exists",
            "requirements": [
                {
                    "dockerPull": "alpine:3.10.0",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "mkdir",
                "-p"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#mkdir.cwl/dir_name"
                }
            ],
            "id": "#mkdir.cwl",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.dir_name)"
                    },
                    "id": "#mkdir.cwl/created_directory"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "salmon"
            ],
            "inputs": [
                {
                    "id": "#salmon-index.cwl/index",
                    "type": "string",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--index"
                    }
                },
                {
                    "id": "#salmon-index.cwl/threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--threads"
                    },
                    "doc": "1\nint: number of threads to run Salmon\n"
                },
                {
                    "id": "#salmon-index.cwl/transcripts",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--transcripts"
                    }
                },
                {
                    "id": "#salmon-index.cwl/gencode",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--gencode"
                    }
                },
                {
                    "id": "#salmon-index.cwl/kmer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-k"
                    }
                }
            ],
            "outputs": [
                {
                    "$import": "#salmon-index.cwl/index"
                }
            ],
            "arguments": [
                "index"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "combinelab/salmon:1.1.0"
                }
            ],
            "id": "#salmon-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "STAR",
                "--runMode",
                "genomeGenerate"
            ],
            "inputs": [
                {
                    "id": "#star_index.cwl/genomeDir",
                    "type": "Directory",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--genomeDir"
                    }
                },
                {
                    "id": "#star_index.cwl/genomeFastaFiles",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--genomeFastaFiles"
                    }
                },
                {
                    "id": "#star_index.cwl/runThreadN",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--runThreadN"
                    }
                },
                {
                    "id": "#star_index.cwl/sjdbGTFfile",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--sjdbGTFfile"
                    }
                },
                {
                    "id": "#star_index.cwl/sjdbOverhang",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--sjdbOverhang"
                    }
                },
                {
                    "id": "#star_index.cwl/genomeSAindexNbases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--genomeSAindexNbases"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#star_index.cwl/starIndex",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.genomeDir.basename)"
                    }
                }
            ],
            "doc": "STAR: Spliced Transcripts Alignment to a Reference. https://github.com/alexdobin/STAR/blob/master/doc/STARmanual.pdf",
            "label": "STAR genomeGenerate: Generating genome indexes.",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.genomeDir)",
                            "writable": true
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/star:2.7.1a--0"
                }
            ],
            "id": "#star_index.cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ],
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "createindex_singlevirus",
            "doc": "VIRTUS v1.1",
            "inputs": [
                {
                    "id": "#main/dir_name_STAR",
                    "type": "string",
                    "https://www.sevenbridges.com/x": -723,
                    "https://www.sevenbridges.com/y": -122
                },
                {
                    "id": "#main/runThreadN",
                    "type": [
                        "null",
                        "int"
                    ],
                    "https://www.sevenbridges.com/x": -566,
                    "https://www.sevenbridges.com/y": -675
                },
                {
                    "id": "#main/genomeFastaFiles",
                    "type": "File",
                    "https://www.sevenbridges.com/x": -564.734375,
                    "https://www.sevenbridges.com/y": -338
                },
                {
                    "id": "#main/genomeSAindexNbases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "For small genome such as single virus, this value need to be small.",
                    "https://www.sevenbridges.com/x": -563,
                    "https://www.sevenbridges.com/y": -516
                },
                {
                    "id": "#main/transcripts",
                    "type": "File",
                    "https://www.sevenbridges.com/x": -570,
                    "https://www.sevenbridges.com/y": 54
                },
                {
                    "id": "#main/index_salmon",
                    "type": "string",
                    "https://www.sevenbridges.com/x": -578,
                    "https://www.sevenbridges.com/y": 216
                }
            ],
            "outputs": [
                {
                    "id": "#main/starIndex",
                    "outputSource": [
                        "#main/star_index/starIndex"
                    ],
                    "type": "Directory",
                    "https://www.sevenbridges.com/x": 36.765625,
                    "https://www.sevenbridges.com/y": -256
                },
                {
                    "id": "#main/index",
                    "outputSource": [
                        "#main/salmon_index/index"
                    ],
                    "type": "Directory",
                    "https://www.sevenbridges.com/x": 29.8203125,
                    "https://www.sevenbridges.com/y": 159
                }
            ],
            "steps": [
                {
                    "id": "#main/star_index",
                    "in": [
                        {
                            "id": "#main/star_index/genomeDir",
                            "source": "#main/mkdir/created_directory"
                        },
                        {
                            "id": "#main/star_index/genomeFastaFiles",
                            "source": "#main/genomeFastaFiles"
                        },
                        {
                            "id": "#main/star_index/runThreadN",
                            "source": "#main/runThreadN"
                        },
                        {
                            "id": "#main/star_index/genomeSAindexNbases",
                            "default": 10,
                            "source": "#main/genomeSAindexNbases"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/star_index/starIndex"
                        }
                    ],
                    "run": "#star_index.cwl",
                    "label": "STAR genomeGenerate: Generating genome indexes.",
                    "https://www.sevenbridges.com/x": -184,
                    "https://www.sevenbridges.com/y": -256
                },
                {
                    "id": "#main/mkdir",
                    "in": [
                        {
                            "id": "#main/mkdir/dir_name",
                            "source": "#main/dir_name_STAR"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/mkdir/created_directory"
                        }
                    ],
                    "run": "#mkdir.cwl",
                    "label": "Make directory if not exists",
                    "https://www.sevenbridges.com/x": -548,
                    "https://www.sevenbridges.com/y": -123
                },
                {
                    "id": "#main/salmon_index",
                    "in": [
                        {
                            "id": "#main/salmon_index/index",
                            "source": "#main/index_salmon"
                        },
                        {
                            "id": "#main/salmon_index/threads",
                            "source": "#main/runThreadN"
                        },
                        {
                            "id": "#main/salmon_index/transcripts",
                            "source": "#main/transcripts"
                        },
                        {
                            "id": "#main/salmon_index/kmer",
                            "default": 31
                        },
                        {
                            "id": "#main/salmon_index/type",
                            "default": "quasi"
                        }
                    ],
                    "out": [
                        {
                            "$import": "#main/salmon_index/index"
                        }
                    ],
                    "run": "#salmon-index.cwl",
                    "https://www.sevenbridges.com/x": -186,
                    "https://www.sevenbridges.com/y": 158
                }
            ],
            "requirements": []
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://www.sevenbridges.com/"
    }
}
